/****************************************************************************
** Meta object code from reading C++ file 'qquicktriggermode_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/extras/qquicktriggermode_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquicktriggermode_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickActivationMode_t {
    QByteArrayData data[5];
    char stringdata0[86];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickActivationMode_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickActivationMode_t qt_meta_stringdata_QQuickActivationMode = {
    {
QT_MOC_LITERAL(0, 0, 20), // "QQuickActivationMode"
QT_MOC_LITERAL(1, 21, 14), // "ActivationMode"
QT_MOC_LITERAL(2, 36, 15), // "ActivateOnPress"
QT_MOC_LITERAL(3, 52, 17), // "ActivateOnRelease"
QT_MOC_LITERAL(4, 70, 15) // "ActivateOnClick"

    },
    "QQuickActivationMode\0ActivationMode\0"
    "ActivateOnPress\0ActivateOnRelease\0"
    "ActivateOnClick"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickActivationMode[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       1,   14, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // enums: name, alias, flags, count, data
       1,    1, 0x0,    3,   19,

 // enum data: key, value
       2, uint(QQuickActivationMode::ActivateOnPress),
       3, uint(QQuickActivationMode::ActivateOnRelease),
       4, uint(QQuickActivationMode::ActivateOnClick),

       0        // eod
};

QT_INIT_METAOBJECT const QMetaObject QQuickActivationMode::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_QQuickActivationMode.data,
    qt_meta_data_QQuickActivationMode,
    nullptr,
    nullptr,
    nullptr
} };

struct qt_meta_stringdata_QQuickTriggerMode_t {
    QByteArrayData data[5];
    char stringdata0[77];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickTriggerMode_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickTriggerMode_t qt_meta_stringdata_QQuickTriggerMode = {
    {
QT_MOC_LITERAL(0, 0, 17), // "QQuickTriggerMode"
QT_MOC_LITERAL(1, 18, 11), // "TriggerMode"
QT_MOC_LITERAL(2, 30, 14), // "TriggerOnPress"
QT_MOC_LITERAL(3, 45, 16), // "TriggerOnRelease"
QT_MOC_LITERAL(4, 62, 14) // "TriggerOnClick"

    },
    "QQuickTriggerMode\0TriggerMode\0"
    "TriggerOnPress\0TriggerOnRelease\0"
    "TriggerOnClick"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickTriggerMode[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       1,   14, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // enums: name, alias, flags, count, data
       1,    1, 0x0,    3,   19,

 // enum data: key, value
       2, uint(QQuickTriggerMode::TriggerOnPress),
       3, uint(QQuickTriggerMode::TriggerOnRelease),
       4, uint(QQuickTriggerMode::TriggerOnClick),

       0        // eod
};

QT_INIT_METAOBJECT const QMetaObject QQuickTriggerMode::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_QQuickTriggerMode.data,
    qt_meta_data_QQuickTriggerMode,
    nullptr,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
