/****************************************************************************
** Meta object code from reading C++ file 'qquickabstractmessagedialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/dialogs/qquickabstractmessagedialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickabstractmessagedialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickAbstractMessageDialog_t {
    QByteArrayData data[44];
    char stringdata0[583];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickAbstractMessageDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickAbstractMessageDialog_t qt_meta_stringdata_QQuickAbstractMessageDialog = {
    {
QT_MOC_LITERAL(0, 0, 27), // "QQuickAbstractMessageDialog"
QT_MOC_LITERAL(1, 28, 11), // "textChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 22), // "informativeTextChanged"
QT_MOC_LITERAL(4, 64, 19), // "detailedTextChanged"
QT_MOC_LITERAL(5, 84, 11), // "iconChanged"
QT_MOC_LITERAL(6, 96, 22), // "standardButtonsChanged"
QT_MOC_LITERAL(7, 119, 13), // "buttonClicked"
QT_MOC_LITERAL(8, 133, 7), // "discard"
QT_MOC_LITERAL(9, 141, 4), // "help"
QT_MOC_LITERAL(10, 146, 3), // "yes"
QT_MOC_LITERAL(11, 150, 2), // "no"
QT_MOC_LITERAL(12, 153, 5), // "apply"
QT_MOC_LITERAL(13, 159, 5), // "reset"
QT_MOC_LITERAL(14, 165, 10), // "setVisible"
QT_MOC_LITERAL(15, 176, 1), // "v"
QT_MOC_LITERAL(16, 178, 8), // "setTitle"
QT_MOC_LITERAL(17, 187, 3), // "arg"
QT_MOC_LITERAL(18, 191, 7), // "setText"
QT_MOC_LITERAL(19, 199, 18), // "setInformativeText"
QT_MOC_LITERAL(20, 218, 15), // "setDetailedText"
QT_MOC_LITERAL(21, 234, 7), // "setIcon"
QT_MOC_LITERAL(22, 242, 4), // "Icon"
QT_MOC_LITERAL(23, 247, 4), // "icon"
QT_MOC_LITERAL(24, 252, 18), // "setStandardButtons"
QT_MOC_LITERAL(25, 271, 15), // "StandardButtons"
QT_MOC_LITERAL(26, 287, 7), // "buttons"
QT_MOC_LITERAL(27, 295, 5), // "click"
QT_MOC_LITERAL(28, 301, 36), // "QQuickAbstractDialog::Standar..."
QT_MOC_LITERAL(29, 338, 6), // "button"
QT_MOC_LITERAL(30, 345, 37), // "QPlatformDialogHelper::Standa..."
QT_MOC_LITERAL(31, 383, 33), // "QPlatformDialogHelper::Button..."
QT_MOC_LITERAL(32, 417, 4), // "text"
QT_MOC_LITERAL(33, 422, 15), // "informativeText"
QT_MOC_LITERAL(34, 438, 12), // "detailedText"
QT_MOC_LITERAL(35, 451, 18), // "standardIconSource"
QT_MOC_LITERAL(36, 470, 15), // "standardButtons"
QT_MOC_LITERAL(37, 486, 37), // "QQuickAbstractDialog::Standar..."
QT_MOC_LITERAL(38, 524, 13), // "clickedButton"
QT_MOC_LITERAL(39, 538, 6), // "NoIcon"
QT_MOC_LITERAL(40, 545, 11), // "Information"
QT_MOC_LITERAL(41, 557, 7), // "Warning"
QT_MOC_LITERAL(42, 565, 8), // "Critical"
QT_MOC_LITERAL(43, 574, 8) // "Question"

    },
    "QQuickAbstractMessageDialog\0textChanged\0"
    "\0informativeTextChanged\0detailedTextChanged\0"
    "iconChanged\0standardButtonsChanged\0"
    "buttonClicked\0discard\0help\0yes\0no\0"
    "apply\0reset\0setVisible\0v\0setTitle\0arg\0"
    "setText\0setInformativeText\0setDetailedText\0"
    "setIcon\0Icon\0icon\0setStandardButtons\0"
    "StandardButtons\0buttons\0click\0"
    "QQuickAbstractDialog::StandardButton\0"
    "button\0QPlatformDialogHelper::StandardButton\0"
    "QPlatformDialogHelper::ButtonRole\0"
    "text\0informativeText\0detailedText\0"
    "standardIconSource\0standardButtons\0"
    "QQuickAbstractDialog::StandardButtons\0"
    "clickedButton\0NoIcon\0Information\0"
    "Warning\0Critical\0Question"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickAbstractMessageDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       7,  160, // properties
       1,  188, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,
       3,    0,  120,    2, 0x06 /* Public */,
       4,    0,  121,    2, 0x06 /* Public */,
       5,    0,  122,    2, 0x06 /* Public */,
       6,    0,  123,    2, 0x06 /* Public */,
       7,    0,  124,    2, 0x06 /* Public */,
       8,    0,  125,    2, 0x06 /* Public */,
       9,    0,  126,    2, 0x06 /* Public */,
      10,    0,  127,    2, 0x06 /* Public */,
      11,    0,  128,    2, 0x06 /* Public */,
      12,    0,  129,    2, 0x06 /* Public */,
      13,    0,  130,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,  131,    2, 0x0a /* Public */,
      16,    1,  134,    2, 0x0a /* Public */,
      18,    1,  137,    2, 0x0a /* Public */,
      19,    1,  140,    2, 0x0a /* Public */,
      20,    1,  143,    2, 0x0a /* Public */,
      21,    1,  146,    2, 0x0a /* Public */,
      24,    1,  149,    2, 0x0a /* Public */,
      27,    1,  152,    2, 0x0a /* Public */,
      27,    2,  155,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, 0x80000000 | 28,   29,
    QMetaType::Void, 0x80000000 | 30, 0x80000000 | 31,   29,    2,

 // properties: name, type, flags
      32, QMetaType::QString, 0x00495103,
      33, QMetaType::QString, 0x00495103,
      34, QMetaType::QString, 0x00495103,
      23, 0x80000000 | 22, 0x0049510b,
      35, QMetaType::QUrl, 0x00495001,
      36, 0x80000000 | 37, 0x0049510b,
      38, 0x80000000 | 28, 0x00495009,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       3,
       4,
       5,

 // enums: name, alias, flags, count, data
      22,   22, 0x0,    5,  193,

 // enum data: key, value
      39, uint(QQuickAbstractMessageDialog::NoIcon),
      40, uint(QQuickAbstractMessageDialog::Information),
      41, uint(QQuickAbstractMessageDialog::Warning),
      42, uint(QQuickAbstractMessageDialog::Critical),
      43, uint(QQuickAbstractMessageDialog::Question),

       0        // eod
};

void QQuickAbstractMessageDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickAbstractMessageDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->textChanged(); break;
        case 1: _t->informativeTextChanged(); break;
        case 2: _t->detailedTextChanged(); break;
        case 3: _t->iconChanged(); break;
        case 4: _t->standardButtonsChanged(); break;
        case 5: _t->buttonClicked(); break;
        case 6: _t->discard(); break;
        case 7: _t->help(); break;
        case 8: _t->yes(); break;
        case 9: _t->no(); break;
        case 10: _t->apply(); break;
        case 11: _t->reset(); break;
        case 12: _t->setVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->setInformativeText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->setDetailedText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->setIcon((*reinterpret_cast< Icon(*)>(_a[1]))); break;
        case 18: _t->setStandardButtons((*reinterpret_cast< StandardButtons(*)>(_a[1]))); break;
        case 19: _t->click((*reinterpret_cast< QQuickAbstractDialog::StandardButton(*)>(_a[1]))); break;
        case 20: _t->click((*reinterpret_cast< QPlatformDialogHelper::StandardButton(*)>(_a[1])),(*reinterpret_cast< QPlatformDialogHelper::ButtonRole(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QPlatformDialogHelper::ButtonRole >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QPlatformDialogHelper::StandardButton >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::textChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::informativeTextChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::detailedTextChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::iconChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::standardButtonsChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::buttonClicked)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::discard)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::help)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::yes)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::no)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::apply)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractMessageDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractMessageDialog::reset)) {
                *result = 11;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickAbstractMessageDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->text(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->informativeText(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->detailedText(); break;
        case 3: *reinterpret_cast< Icon*>(_v) = _t->icon(); break;
        case 4: *reinterpret_cast< QUrl*>(_v) = _t->standardIconSource(); break;
        case 5: *reinterpret_cast< QQuickAbstractDialog::StandardButtons*>(_v) = _t->standardButtons(); break;
        case 6: *reinterpret_cast< QQuickAbstractDialog::StandardButton*>(_v) = _t->clickedButton(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickAbstractMessageDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setText(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setInformativeText(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setDetailedText(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setIcon(*reinterpret_cast< Icon*>(_v)); break;
        case 5: _t->setStandardButtons(*reinterpret_cast< QQuickAbstractDialog::StandardButtons*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_QQuickAbstractMessageDialog[] = {
    QMetaObject::SuperData::link<QQuickAbstractDialog::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject QQuickAbstractMessageDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickAbstractDialog::staticMetaObject>(),
    qt_meta_stringdata_QQuickAbstractMessageDialog.data,
    qt_meta_data_QQuickAbstractMessageDialog,
    qt_static_metacall,
    qt_meta_extradata_QQuickAbstractMessageDialog,
    nullptr
} };


const QMetaObject *QQuickAbstractMessageDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickAbstractMessageDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickAbstractMessageDialog.stringdata0))
        return static_cast<void*>(this);
    return QQuickAbstractDialog::qt_metacast(_clname);
}

int QQuickAbstractMessageDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickAbstractDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickAbstractMessageDialog::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickAbstractMessageDialog::informativeTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickAbstractMessageDialog::detailedTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickAbstractMessageDialog::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickAbstractMessageDialog::standardButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickAbstractMessageDialog::buttonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickAbstractMessageDialog::discard()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuickAbstractMessageDialog::help()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuickAbstractMessageDialog::yes()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuickAbstractMessageDialog::no()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuickAbstractMessageDialog::apply()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuickAbstractMessageDialog::reset()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
