/****************************************************************************
** Meta object code from reading C++ file 'qquickabstractdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/dialogs/qquickabstractdialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickabstractdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickAbstractDialog_t {
    QByteArrayData data[57];
    char stringdata0[560];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickAbstractDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickAbstractDialog_t qt_meta_stringdata_QQuickAbstractDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "QQuickAbstractDialog"
QT_MOC_LITERAL(1, 21, 17), // "visibilityChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 15), // "geometryChanged"
QT_MOC_LITERAL(4, 56, 15), // "modalityChanged"
QT_MOC_LITERAL(5, 72, 12), // "titleChanged"
QT_MOC_LITERAL(6, 85, 8), // "accepted"
QT_MOC_LITERAL(7, 94, 8), // "rejected"
QT_MOC_LITERAL(8, 103, 25), // "__maximumDimensionChanged"
QT_MOC_LITERAL(9, 129, 4), // "open"
QT_MOC_LITERAL(10, 134, 5), // "close"
QT_MOC_LITERAL(11, 140, 4), // "setX"
QT_MOC_LITERAL(12, 145, 3), // "arg"
QT_MOC_LITERAL(13, 149, 4), // "setY"
QT_MOC_LITERAL(14, 154, 8), // "setWidth"
QT_MOC_LITERAL(15, 163, 9), // "setHeight"
QT_MOC_LITERAL(16, 173, 16), // "decorationLoaded"
QT_MOC_LITERAL(17, 190, 6), // "accept"
QT_MOC_LITERAL(18, 197, 6), // "reject"
QT_MOC_LITERAL(19, 204, 14), // "visibleChanged"
QT_MOC_LITERAL(20, 219, 1), // "v"
QT_MOC_LITERAL(21, 221, 21), // "windowGeometryChanged"
QT_MOC_LITERAL(22, 243, 19), // "minimumWidthChanged"
QT_MOC_LITERAL(23, 263, 20), // "minimumHeightChanged"
QT_MOC_LITERAL(24, 284, 21), // "implicitHeightChanged"
QT_MOC_LITERAL(25, 306, 7), // "visible"
QT_MOC_LITERAL(26, 314, 8), // "modality"
QT_MOC_LITERAL(27, 323, 18), // "Qt::WindowModality"
QT_MOC_LITERAL(28, 342, 5), // "title"
QT_MOC_LITERAL(29, 348, 8), // "isWindow"
QT_MOC_LITERAL(30, 357, 1), // "x"
QT_MOC_LITERAL(31, 359, 1), // "y"
QT_MOC_LITERAL(32, 361, 5), // "width"
QT_MOC_LITERAL(33, 367, 6), // "height"
QT_MOC_LITERAL(34, 374, 18), // "__maximumDimension"
QT_MOC_LITERAL(35, 393, 14), // "StandardButton"
QT_MOC_LITERAL(36, 408, 8), // "NoButton"
QT_MOC_LITERAL(37, 417, 2), // "Ok"
QT_MOC_LITERAL(38, 420, 4), // "Save"
QT_MOC_LITERAL(39, 425, 7), // "SaveAll"
QT_MOC_LITERAL(40, 433, 4), // "Open"
QT_MOC_LITERAL(41, 438, 3), // "Yes"
QT_MOC_LITERAL(42, 442, 8), // "YesToAll"
QT_MOC_LITERAL(43, 451, 2), // "No"
QT_MOC_LITERAL(44, 454, 7), // "NoToAll"
QT_MOC_LITERAL(45, 462, 5), // "Abort"
QT_MOC_LITERAL(46, 468, 5), // "Retry"
QT_MOC_LITERAL(47, 474, 6), // "Ignore"
QT_MOC_LITERAL(48, 481, 5), // "Close"
QT_MOC_LITERAL(49, 487, 6), // "Cancel"
QT_MOC_LITERAL(50, 494, 7), // "Discard"
QT_MOC_LITERAL(51, 502, 4), // "Help"
QT_MOC_LITERAL(52, 507, 5), // "Apply"
QT_MOC_LITERAL(53, 513, 5), // "Reset"
QT_MOC_LITERAL(54, 519, 15), // "RestoreDefaults"
QT_MOC_LITERAL(55, 535, 8), // "NButtons"
QT_MOC_LITERAL(56, 544, 15) // "StandardButtons"

    },
    "QQuickAbstractDialog\0visibilityChanged\0"
    "\0geometryChanged\0modalityChanged\0"
    "titleChanged\0accepted\0rejected\0"
    "__maximumDimensionChanged\0open\0close\0"
    "setX\0arg\0setY\0setWidth\0setHeight\0"
    "decorationLoaded\0accept\0reject\0"
    "visibleChanged\0v\0windowGeometryChanged\0"
    "minimumWidthChanged\0minimumHeightChanged\0"
    "implicitHeightChanged\0visible\0modality\0"
    "Qt::WindowModality\0title\0isWindow\0x\0"
    "y\0width\0height\0__maximumDimension\0"
    "StandardButton\0NoButton\0Ok\0Save\0SaveAll\0"
    "Open\0Yes\0YesToAll\0No\0NoToAll\0Abort\0"
    "Retry\0Ignore\0Close\0Cancel\0Discard\0"
    "Help\0Apply\0Reset\0RestoreDefaults\0"
    "NButtons\0StandardButtons"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickAbstractDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       9,  150, // properties
       2,  186, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,
       3,    0,  120,    2, 0x06 /* Public */,
       4,    0,  121,    2, 0x06 /* Public */,
       5,    0,  122,    2, 0x06 /* Public */,
       6,    0,  123,    2, 0x06 /* Public */,
       7,    0,  124,    2, 0x06 /* Public */,
       8,    0,  125,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,  126,    2, 0x0a /* Public */,
      10,    0,  127,    2, 0x0a /* Public */,
      11,    1,  128,    2, 0x0a /* Public */,
      13,    1,  131,    2, 0x0a /* Public */,
      14,    1,  134,    2, 0x0a /* Public */,
      15,    1,  137,    2, 0x0a /* Public */,
      16,    0,  140,    2, 0x09 /* Protected */,
      17,    0,  141,    2, 0x09 /* Protected */,
      18,    0,  142,    2, 0x09 /* Protected */,
      19,    1,  143,    2, 0x09 /* Protected */,
      21,    0,  146,    2, 0x09 /* Protected */,
      22,    0,  147,    2, 0x09 /* Protected */,
      23,    0,  148,    2, 0x09 /* Protected */,
      24,    0,  149,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      25, QMetaType::Bool, 0x00495103,
      26, 0x80000000 | 27, 0x0049510b,
      28, QMetaType::QString, 0x00495103,
      29, QMetaType::Bool, 0x00095401,
      30, QMetaType::Int, 0x00495103,
      31, QMetaType::Int, 0x00495103,
      32, QMetaType::Int, 0x00495103,
      33, QMetaType::Int, 0x00495103,
      34, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       2,
       3,
       0,
       1,
       1,
       1,
       1,
       6,

 // enums: name, alias, flags, count, data
      35,   35, 0x0,   20,  196,
      56,   35, 0x1,   20,  236,

 // enum data: key, value
      36, uint(QQuickAbstractDialog::NoButton),
      37, uint(QQuickAbstractDialog::Ok),
      38, uint(QQuickAbstractDialog::Save),
      39, uint(QQuickAbstractDialog::SaveAll),
      40, uint(QQuickAbstractDialog::Open),
      41, uint(QQuickAbstractDialog::Yes),
      42, uint(QQuickAbstractDialog::YesToAll),
      43, uint(QQuickAbstractDialog::No),
      44, uint(QQuickAbstractDialog::NoToAll),
      45, uint(QQuickAbstractDialog::Abort),
      46, uint(QQuickAbstractDialog::Retry),
      47, uint(QQuickAbstractDialog::Ignore),
      48, uint(QQuickAbstractDialog::Close),
      49, uint(QQuickAbstractDialog::Cancel),
      50, uint(QQuickAbstractDialog::Discard),
      51, uint(QQuickAbstractDialog::Help),
      52, uint(QQuickAbstractDialog::Apply),
      53, uint(QQuickAbstractDialog::Reset),
      54, uint(QQuickAbstractDialog::RestoreDefaults),
      55, uint(QQuickAbstractDialog::NButtons),
      36, uint(QQuickAbstractDialog::NoButton),
      37, uint(QQuickAbstractDialog::Ok),
      38, uint(QQuickAbstractDialog::Save),
      39, uint(QQuickAbstractDialog::SaveAll),
      40, uint(QQuickAbstractDialog::Open),
      41, uint(QQuickAbstractDialog::Yes),
      42, uint(QQuickAbstractDialog::YesToAll),
      43, uint(QQuickAbstractDialog::No),
      44, uint(QQuickAbstractDialog::NoToAll),
      45, uint(QQuickAbstractDialog::Abort),
      46, uint(QQuickAbstractDialog::Retry),
      47, uint(QQuickAbstractDialog::Ignore),
      48, uint(QQuickAbstractDialog::Close),
      49, uint(QQuickAbstractDialog::Cancel),
      50, uint(QQuickAbstractDialog::Discard),
      51, uint(QQuickAbstractDialog::Help),
      52, uint(QQuickAbstractDialog::Apply),
      53, uint(QQuickAbstractDialog::Reset),
      54, uint(QQuickAbstractDialog::RestoreDefaults),
      55, uint(QQuickAbstractDialog::NButtons),

       0        // eod
};

void QQuickAbstractDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickAbstractDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->visibilityChanged(); break;
        case 1: _t->geometryChanged(); break;
        case 2: _t->modalityChanged(); break;
        case 3: _t->titleChanged(); break;
        case 4: _t->accepted(); break;
        case 5: _t->rejected(); break;
        case 6: _t->__maximumDimensionChanged(); break;
        case 7: _t->open(); break;
        case 8: _t->close(); break;
        case 9: _t->setX((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->setY((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->setWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->setHeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->decorationLoaded(); break;
        case 14: _t->accept(); break;
        case 15: _t->reject(); break;
        case 16: _t->visibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->windowGeometryChanged(); break;
        case 18: _t->minimumWidthChanged(); break;
        case 19: _t->minimumHeightChanged(); break;
        case 20: _t->implicitHeightChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::visibilityChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::geometryChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::modalityChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::titleChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::accepted)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::rejected)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractDialog::__maximumDimensionChanged)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickAbstractDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isVisible(); break;
        case 1: *reinterpret_cast< Qt::WindowModality*>(_v) = _t->modality(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isWindow(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->x(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->y(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->width(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->height(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->__maximumDimension(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickAbstractDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisible(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setModality(*reinterpret_cast< Qt::WindowModality*>(_v)); break;
        case 2: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setX(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setY(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setWidth(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setHeight(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QQuickAbstractDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QQuickAbstractDialog.data,
    qt_meta_data_QQuickAbstractDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickAbstractDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickAbstractDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickAbstractDialog.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuickAbstractDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickAbstractDialog::visibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickAbstractDialog::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickAbstractDialog::modalityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickAbstractDialog::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickAbstractDialog::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickAbstractDialog::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickAbstractDialog::__maximumDimensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
