/****************************************************************************
** Meta object code from reading C++ file 'qquickmenu_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/controls/qquickmenu_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickmenu_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickMenu1_t {
    QByteArrayData data[56];
    char stringdata0[784];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickMenu1_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickMenu1_t qt_meta_stringdata_QQuickMenu1 = {
    {
QT_MOC_LITERAL(0, 0, 11), // "QQuickMenu1"
QT_MOC_LITERAL(1, 12, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 28, 5), // "items"
QT_MOC_LITERAL(3, 34, 12), // "itemsChanged"
QT_MOC_LITERAL(4, 47, 0), // ""
QT_MOC_LITERAL(5, 48, 12), // "titleChanged"
QT_MOC_LITERAL(6, 61, 22), // "__selectedIndexChanged"
QT_MOC_LITERAL(7, 84, 11), // "aboutToShow"
QT_MOC_LITERAL(8, 96, 11), // "aboutToHide"
QT_MOC_LITERAL(9, 108, 19), // "popupVisibleChanged"
QT_MOC_LITERAL(10, 128, 20), // "__menuPopupDestroyed"
QT_MOC_LITERAL(11, 149, 22), // "__popupGeometryChanged"
QT_MOC_LITERAL(12, 172, 22), // "menuContentItemChanged"
QT_MOC_LITERAL(13, 195, 19), // "minimumWidthChanged"
QT_MOC_LITERAL(14, 215, 14), // "__proxyChanged"
QT_MOC_LITERAL(15, 230, 13), // "__dismissMenu"
QT_MOC_LITERAL(16, 244, 17), // "__closeAndDestroy"
QT_MOC_LITERAL(17, 262, 19), // "__dismissAndDestroy"
QT_MOC_LITERAL(18, 282, 19), // "updateSelectedIndex"
QT_MOC_LITERAL(19, 302, 18), // "setMenuContentItem"
QT_MOC_LITERAL(20, 321, 11), // "QQuickItem*"
QT_MOC_LITERAL(21, 333, 15), // "setPopupVisible"
QT_MOC_LITERAL(22, 349, 8), // "hideMenu"
QT_MOC_LITERAL(23, 358, 16), // "clearPopupWindow"
QT_MOC_LITERAL(24, 375, 10), // "updateText"
QT_MOC_LITERAL(25, 386, 20), // "windowVisibleChanged"
QT_MOC_LITERAL(26, 407, 32), // "platformMenuWindowVisibleChanged"
QT_MOC_LITERAL(27, 440, 5), // "popup"
QT_MOC_LITERAL(28, 446, 7), // "addItem"
QT_MOC_LITERAL(29, 454, 16), // "QQuickMenuItem1*"
QT_MOC_LITERAL(30, 471, 10), // "insertItem"
QT_MOC_LITERAL(31, 482, 12), // "addSeparator"
QT_MOC_LITERAL(32, 495, 15), // "insertSeparator"
QT_MOC_LITERAL(33, 511, 16), // "QQuickMenuBase1*"
QT_MOC_LITERAL(34, 528, 10), // "removeItem"
QT_MOC_LITERAL(35, 539, 5), // "clear"
QT_MOC_LITERAL(36, 545, 7), // "__popup"
QT_MOC_LITERAL(37, 553, 10), // "targetRect"
QT_MOC_LITERAL(38, 564, 11), // "atItemIndex"
QT_MOC_LITERAL(39, 576, 8), // "MenuType"
QT_MOC_LITERAL(40, 585, 8), // "menuType"
QT_MOC_LITERAL(41, 594, 5), // "title"
QT_MOC_LITERAL(42, 600, 25), // "QQmlListProperty<QObject>"
QT_MOC_LITERAL(43, 626, 15), // "__selectedIndex"
QT_MOC_LITERAL(44, 642, 14), // "__popupVisible"
QT_MOC_LITERAL(45, 657, 13), // "__contentItem"
QT_MOC_LITERAL(46, 671, 14), // "__minimumWidth"
QT_MOC_LITERAL(47, 686, 6), // "__font"
QT_MOC_LITERAL(48, 693, 9), // "__xOffset"
QT_MOC_LITERAL(49, 703, 9), // "__yOffset"
QT_MOC_LITERAL(50, 713, 8), // "__action"
QT_MOC_LITERAL(51, 722, 14), // "QQuickAction1*"
QT_MOC_LITERAL(52, 737, 15), // "__popupGeometry"
QT_MOC_LITERAL(53, 753, 9), // "__isProxy"
QT_MOC_LITERAL(54, 763, 11), // "DefaultMenu"
QT_MOC_LITERAL(55, 775, 8) // "EditMenu"

    },
    "QQuickMenu1\0DefaultProperty\0items\0"
    "itemsChanged\0\0titleChanged\0"
    "__selectedIndexChanged\0aboutToShow\0"
    "aboutToHide\0popupVisibleChanged\0"
    "__menuPopupDestroyed\0__popupGeometryChanged\0"
    "menuContentItemChanged\0minimumWidthChanged\0"
    "__proxyChanged\0__dismissMenu\0"
    "__closeAndDestroy\0__dismissAndDestroy\0"
    "updateSelectedIndex\0setMenuContentItem\0"
    "QQuickItem*\0setPopupVisible\0hideMenu\0"
    "clearPopupWindow\0updateText\0"
    "windowVisibleChanged\0"
    "platformMenuWindowVisibleChanged\0popup\0"
    "addItem\0QQuickMenuItem1*\0insertItem\0"
    "addSeparator\0insertSeparator\0"
    "QQuickMenuBase1*\0removeItem\0clear\0"
    "__popup\0targetRect\0atItemIndex\0MenuType\0"
    "menuType\0title\0QQmlListProperty<QObject>\0"
    "__selectedIndex\0__popupVisible\0"
    "__contentItem\0__minimumWidth\0__font\0"
    "__xOffset\0__yOffset\0__action\0"
    "QQuickAction1*\0__popupGeometry\0__isProxy\0"
    "DefaultMenu\0EditMenu"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickMenu1[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      33,   16, // methods
      12,  248, // properties
       1,  296, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,  181,    4, 0x06 /* Public */,
       5,    0,  182,    4, 0x06 /* Public */,
       6,    0,  183,    4, 0x06 /* Public */,
       7,    0,  184,    4, 0x06 /* Public */,
       8,    0,  185,    4, 0x06 /* Public */,
       9,    0,  186,    4, 0x06 /* Public */,
      10,    0,  187,    4, 0x06 /* Public */,
      11,    0,  188,    4, 0x06 /* Public */,
      12,    0,  189,    4, 0x06 /* Public */,
      13,    0,  190,    4, 0x06 /* Public */,
      14,    0,  191,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    0,  192,    4, 0x0a /* Public */,
      16,    0,  193,    4, 0x0a /* Public */,
      17,    0,  194,    4, 0x0a /* Public */,
      18,    0,  195,    4, 0x09 /* Protected */,
      19,    1,  196,    4, 0x09 /* Protected */,
      21,    1,  199,    4, 0x09 /* Protected */,
      22,    0,  202,    4, 0x09 /* Protected */,
      23,    0,  203,    4, 0x09 /* Protected */,
      24,    0,  204,    4, 0x09 /* Protected */,
      25,    1,  205,    4, 0x09 /* Protected */,
      26,    1,  208,    4, 0x09 /* Protected */,

 // methods: name, argc, parameters, tag, flags
      27,    0,  211,    4, 0x02 /* Public */,
      28,    1,  212,    4, 0x02 /* Public */,
      30,    2,  215,    4, 0x02 /* Public */,
      31,    0,  220,    4, 0x02 /* Public */,
      32,    1,  221,    4, 0x02 /* Public */,
      30,    2,  224,    4, 0x02 /* Public */,
      34,    1,  229,    4, 0x02 /* Public */,
      35,    0,  232,    4, 0x02 /* Public */,
      36,    3,  233,    4, 0x02 /* Public */,
      36,    2,  240,    4, 0x22 /* Public | MethodCloned */,
      36,    1,  245,    4, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,

 // methods: parameters
    QMetaType::Void,
    0x80000000 | 29, QMetaType::QString,    4,
    0x80000000 | 29, QMetaType::Int, QMetaType::QString,    4,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 33,    4,    4,
    QMetaType::Void, 0x80000000 | 33,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRectF, QMetaType::Int, 0x80000000 | 39,   37,   38,   40,
    QMetaType::Void, QMetaType::QRectF, QMetaType::Int,   37,   38,
    QMetaType::Void, QMetaType::QRectF,   37,

 // properties: name, type, flags
      41, QMetaType::QString, 0x00495003,
       2, 0x80000000 | 42, 0x00495009,
      43, QMetaType::Int, 0x00495003,
      44, QMetaType::Bool, 0x00495001,
      45, 0x80000000 | 20, 0x0049500b,
      46, QMetaType::Int, 0x00495003,
      47, QMetaType::QFont, 0x00095003,
      48, QMetaType::QReal, 0x00095003,
      49, QMetaType::QReal, 0x00095003,
      50, 0x80000000 | 51, 0x00095409,
      52, QMetaType::QRect, 0x00495001,
      53, QMetaType::Bool, 0x00495003,

 // properties: notify_signal_id
       1,
       0,
       2,
       5,
       8,
       9,
       0,
       0,
       0,
       0,
       7,
      10,

 // enums: name, alias, flags, count, data
      39,   39, 0x0,    2,  301,

 // enum data: key, value
      54, uint(QQuickMenu1::DefaultMenu),
      55, uint(QQuickMenu1::EditMenu),

       0        // eod
};

void QQuickMenu1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickMenu1 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->itemsChanged(); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->__selectedIndexChanged(); break;
        case 3: _t->aboutToShow(); break;
        case 4: _t->aboutToHide(); break;
        case 5: _t->popupVisibleChanged(); break;
        case 6: _t->__menuPopupDestroyed(); break;
        case 7: _t->__popupGeometryChanged(); break;
        case 8: _t->menuContentItemChanged(); break;
        case 9: _t->minimumWidthChanged(); break;
        case 10: _t->__proxyChanged(); break;
        case 11: _t->__dismissMenu(); break;
        case 12: _t->__closeAndDestroy(); break;
        case 13: _t->__dismissAndDestroy(); break;
        case 14: _t->updateSelectedIndex(); break;
        case 15: _t->setMenuContentItem((*reinterpret_cast< QQuickItem*(*)>(_a[1]))); break;
        case 16: _t->setPopupVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->hideMenu(); break;
        case 18: _t->clearPopupWindow(); break;
        case 19: _t->updateText(); break;
        case 20: _t->windowVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->platformMenuWindowVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->popup(); break;
        case 23: { QQuickMenuItem1* _r = _t->addItem((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QQuickMenuItem1**>(_a[0]) = std::move(_r); }  break;
        case 24: { QQuickMenuItem1* _r = _t->insertItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QQuickMenuItem1**>(_a[0]) = std::move(_r); }  break;
        case 25: _t->addSeparator(); break;
        case 26: _t->insertSeparator((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->insertItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QQuickMenuBase1*(*)>(_a[2]))); break;
        case 28: _t->removeItem((*reinterpret_cast< QQuickMenuBase1*(*)>(_a[1]))); break;
        case 29: _t->clear(); break;
        case 30: _t->__popup((*reinterpret_cast< const QRectF(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< MenuType(*)>(_a[3]))); break;
        case 31: _t->__popup((*reinterpret_cast< const QRectF(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 32: _t->__popup((*reinterpret_cast< const QRectF(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickMenuBase1* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickMenuBase1* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::itemsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::titleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::__selectedIndexChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::aboutToShow)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::aboutToHide)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::popupVisibleChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::__menuPopupDestroyed)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::__popupGeometryChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::menuContentItemChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::minimumWidthChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QQuickMenu1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickMenu1::__proxyChanged)) {
                *result = 10;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlListProperty<QObject> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickMenu1 *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->text(); break;
        case 1: *reinterpret_cast< QQmlListProperty<QObject>*>(_v) = _t->menuItems(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->selectedIndex(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->popupVisible(); break;
        case 4: *reinterpret_cast< QQuickItem**>(_v) = _t->menuContentItem(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->minimumWidth(); break;
        case 6: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->xOffset(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->yOffset(); break;
        case 9: *reinterpret_cast< QQuickAction1**>(_v) = _t->action(); break;
        case 10: *reinterpret_cast< QRect*>(_v) = _t->popupGeometry(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->isProxy(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickMenu1 *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setText(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setSelectedIndex(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setMenuContentItem(*reinterpret_cast< QQuickItem**>(_v)); break;
        case 5: _t->setMinimumWidth(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setFont(*reinterpret_cast< QFont*>(_v)); break;
        case 7: _t->setXOffset(*reinterpret_cast< qreal*>(_v)); break;
        case 8: _t->setYOffset(*reinterpret_cast< qreal*>(_v)); break;
        case 11: _t->setProxy(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QQuickMenu1::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickMenuText1::staticMetaObject>(),
    qt_meta_stringdata_QQuickMenu1.data,
    qt_meta_data_QQuickMenu1,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickMenu1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickMenu1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickMenu1.stringdata0))
        return static_cast<void*>(this);
    return QQuickMenuText1::qt_metacast(_clname);
}

int QQuickMenu1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickMenuText1::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 12;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 12;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickMenu1::itemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickMenu1::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickMenu1::__selectedIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickMenu1::aboutToShow()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickMenu1::aboutToHide()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickMenu1::popupVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickMenu1::__menuPopupDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuickMenu1::__popupGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuickMenu1::menuContentItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuickMenu1::minimumWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuickMenu1::__proxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
