/****************************************************************************
** Meta object code from reading C++ file 'qquickdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/dialogs/qquickdialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickDialog1_t {
    QByteArrayData data[31];
    char stringdata0[395];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickDialog1_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickDialog1_t qt_meta_stringdata_QQuickDialog1 = {
    {
QT_MOC_LITERAL(0, 0, 13), // "QQuickDialog1"
QT_MOC_LITERAL(1, 14, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 30, 11), // "contentItem"
QT_MOC_LITERAL(3, 42, 12), // "titleChanged"
QT_MOC_LITERAL(4, 55, 0), // ""
QT_MOC_LITERAL(5, 56, 22), // "standardButtonsChanged"
QT_MOC_LITERAL(6, 79, 13), // "buttonClicked"
QT_MOC_LITERAL(7, 93, 7), // "discard"
QT_MOC_LITERAL(8, 101, 4), // "help"
QT_MOC_LITERAL(9, 106, 3), // "yes"
QT_MOC_LITERAL(10, 110, 2), // "no"
QT_MOC_LITERAL(11, 113, 5), // "apply"
QT_MOC_LITERAL(12, 119, 5), // "reset"
QT_MOC_LITERAL(13, 125, 8), // "setTitle"
QT_MOC_LITERAL(14, 134, 3), // "arg"
QT_MOC_LITERAL(15, 138, 18), // "setStandardButtons"
QT_MOC_LITERAL(16, 157, 15), // "StandardButtons"
QT_MOC_LITERAL(17, 173, 7), // "buttons"
QT_MOC_LITERAL(18, 181, 5), // "click"
QT_MOC_LITERAL(19, 187, 36), // "QQuickAbstractDialog::Standar..."
QT_MOC_LITERAL(20, 224, 6), // "button"
QT_MOC_LITERAL(21, 231, 6), // "accept"
QT_MOC_LITERAL(22, 238, 6), // "reject"
QT_MOC_LITERAL(23, 245, 26), // "__standardButtonsLeftModel"
QT_MOC_LITERAL(24, 272, 8), // "QJSValue"
QT_MOC_LITERAL(25, 281, 27), // "__standardButtonsRightModel"
QT_MOC_LITERAL(26, 309, 5), // "title"
QT_MOC_LITERAL(27, 315, 15), // "standardButtons"
QT_MOC_LITERAL(28, 331, 37), // "QQuickAbstractDialog::Standar..."
QT_MOC_LITERAL(29, 369, 13), // "clickedButton"
QT_MOC_LITERAL(30, 383, 11) // "QQuickItem*"

    },
    "QQuickDialog1\0DefaultProperty\0contentItem\0"
    "titleChanged\0\0standardButtonsChanged\0"
    "buttonClicked\0discard\0help\0yes\0no\0"
    "apply\0reset\0setTitle\0arg\0setStandardButtons\0"
    "StandardButtons\0buttons\0click\0"
    "QQuickAbstractDialog::StandardButton\0"
    "button\0accept\0reject\0__standardButtonsLeftModel\0"
    "QJSValue\0__standardButtonsRightModel\0"
    "title\0standardButtons\0"
    "QQuickAbstractDialog::StandardButtons\0"
    "clickedButton\0QQuickItem*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickDialog1[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      16,   16, // methods
       4,  118, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,   96,    4, 0x06 /* Public */,
       5,    0,   97,    4, 0x06 /* Public */,
       6,    0,   98,    4, 0x06 /* Public */,
       7,    0,   99,    4, 0x06 /* Public */,
       8,    0,  100,    4, 0x06 /* Public */,
       9,    0,  101,    4, 0x06 /* Public */,
      10,    0,  102,    4, 0x06 /* Public */,
      11,    0,  103,    4, 0x06 /* Public */,
      12,    0,  104,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,  105,    4, 0x0a /* Public */,
      15,    1,  108,    4, 0x0a /* Public */,
      18,    1,  111,    4, 0x0a /* Public */,
      21,    0,  114,    4, 0x09 /* Protected */,
      22,    0,  115,    4, 0x09 /* Protected */,

 // methods: name, argc, parameters, tag, flags
      23,    0,  116,    4, 0x02 /* Public */,
      25,    0,  117,    4, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    0x80000000 | 24,
    0x80000000 | 24,

 // properties: name, type, flags
      26, QMetaType::QString, 0x00495103,
      27, 0x80000000 | 28, 0x0049510b,
      29, 0x80000000 | 19, 0x00495009,
       2, 0x80000000 | 30, 0x0009410b,

 // properties: notify_signal_id
       0,
       1,
       2,
       0,

 // enums: name, alias, flags, count, data

 // enum data: key, value

       0        // eod
};

void QQuickDialog1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickDialog1 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->standardButtonsChanged(); break;
        case 2: _t->buttonClicked(); break;
        case 3: _t->discard(); break;
        case 4: _t->help(); break;
        case 5: _t->yes(); break;
        case 6: _t->no(); break;
        case 7: _t->apply(); break;
        case 8: _t->reset(); break;
        case 9: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setStandardButtons((*reinterpret_cast< StandardButtons(*)>(_a[1]))); break;
        case 11: _t->click((*reinterpret_cast< QQuickAbstractDialog::StandardButton(*)>(_a[1]))); break;
        case 12: _t->accept(); break;
        case 13: _t->reject(); break;
        case 14: { QJSValue _r = _t->__standardButtonsLeftModel();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: { QJSValue _r = _t->__standardButtonsRightModel();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::titleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::standardButtonsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::buttonClicked)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::discard)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::help)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::yes)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::no)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::apply)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QQuickDialog1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickDialog1::reset)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickDialog1 *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast< QQuickAbstractDialog::StandardButtons*>(_v) = _t->standardButtons(); break;
        case 2: *reinterpret_cast< QQuickAbstractDialog::StandardButton*>(_v) = _t->clickedButton(); break;
        case 3: *reinterpret_cast< QQuickItem**>(_v) = _t->contentItem(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickDialog1 *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setStandardButtons(*reinterpret_cast< QQuickAbstractDialog::StandardButtons*>(_v)); break;
        case 3: _t->setContentItem(*reinterpret_cast< QQuickItem**>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_QQuickDialog1[] = {
    QMetaObject::SuperData::link<QQuickAbstractDialog::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject QQuickDialog1::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickAbstractDialog::staticMetaObject>(),
    qt_meta_stringdata_QQuickDialog1.data,
    qt_meta_data_QQuickDialog1,
    qt_static_metacall,
    qt_meta_extradata_QQuickDialog1,
    nullptr
} };


const QMetaObject *QQuickDialog1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickDialog1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickDialog1.stringdata0))
        return static_cast<void*>(this);
    return QQuickAbstractDialog::qt_metacast(_clname);
}

int QQuickDialog1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickAbstractDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickDialog1::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickDialog1::standardButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickDialog1::buttonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickDialog1::discard()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickDialog1::help()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickDialog1::yes()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickDialog1::no()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuickDialog1::apply()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuickDialog1::reset()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
