/****************************************************************************
** Meta object code from reading C++ file 'qquickabstractfontdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/dialogs/qquickabstractfontdialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickabstractfontdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickAbstractFontDialog_t {
    QByteArrayData data[30];
    char stringdata0[418];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickAbstractFontDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickAbstractFontDialog_t qt_meta_stringdata_QQuickAbstractFontDialog = {
    {
QT_MOC_LITERAL(0, 0, 24), // "QQuickAbstractFontDialog"
QT_MOC_LITERAL(1, 25, 20), // "scalableFontsChanged"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 23), // "nonScalableFontsChanged"
QT_MOC_LITERAL(4, 71, 22), // "monospacedFontsChanged"
QT_MOC_LITERAL(5, 94, 24), // "proportionalFontsChanged"
QT_MOC_LITERAL(6, 119, 11), // "fontChanged"
QT_MOC_LITERAL(7, 131, 18), // "currentFontChanged"
QT_MOC_LITERAL(8, 150, 17), // "selectionAccepted"
QT_MOC_LITERAL(9, 168, 10), // "setVisible"
QT_MOC_LITERAL(10, 179, 1), // "v"
QT_MOC_LITERAL(11, 181, 11), // "setModality"
QT_MOC_LITERAL(12, 193, 18), // "Qt::WindowModality"
QT_MOC_LITERAL(13, 212, 1), // "m"
QT_MOC_LITERAL(14, 214, 8), // "setTitle"
QT_MOC_LITERAL(15, 223, 1), // "t"
QT_MOC_LITERAL(16, 225, 7), // "setFont"
QT_MOC_LITERAL(17, 233, 3), // "arg"
QT_MOC_LITERAL(18, 237, 14), // "setCurrentFont"
QT_MOC_LITERAL(19, 252, 16), // "setScalableFonts"
QT_MOC_LITERAL(20, 269, 19), // "setNonScalableFonts"
QT_MOC_LITERAL(21, 289, 18), // "setMonospacedFonts"
QT_MOC_LITERAL(22, 308, 20), // "setProportionalFonts"
QT_MOC_LITERAL(23, 329, 6), // "accept"
QT_MOC_LITERAL(24, 336, 13), // "scalableFonts"
QT_MOC_LITERAL(25, 350, 16), // "nonScalableFonts"
QT_MOC_LITERAL(26, 367, 15), // "monospacedFonts"
QT_MOC_LITERAL(27, 383, 17), // "proportionalFonts"
QT_MOC_LITERAL(28, 401, 4), // "font"
QT_MOC_LITERAL(29, 406, 11) // "currentFont"

    },
    "QQuickAbstractFontDialog\0scalableFontsChanged\0"
    "\0nonScalableFontsChanged\0"
    "monospacedFontsChanged\0proportionalFontsChanged\0"
    "fontChanged\0currentFontChanged\0"
    "selectionAccepted\0setVisible\0v\0"
    "setModality\0Qt::WindowModality\0m\0"
    "setTitle\0t\0setFont\0arg\0setCurrentFont\0"
    "setScalableFonts\0setNonScalableFonts\0"
    "setMonospacedFonts\0setProportionalFonts\0"
    "accept\0scalableFonts\0nonScalableFonts\0"
    "monospacedFonts\0proportionalFonts\0"
    "font\0currentFont"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickAbstractFontDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       6,  134, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x06 /* Public */,
       3,    0,  100,    2, 0x06 /* Public */,
       4,    0,  101,    2, 0x06 /* Public */,
       5,    0,  102,    2, 0x06 /* Public */,
       6,    0,  103,    2, 0x06 /* Public */,
       7,    0,  104,    2, 0x06 /* Public */,
       8,    0,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,  106,    2, 0x0a /* Public */,
      11,    1,  109,    2, 0x0a /* Public */,
      14,    1,  112,    2, 0x0a /* Public */,
      16,    1,  115,    2, 0x0a /* Public */,
      18,    1,  118,    2, 0x0a /* Public */,
      19,    1,  121,    2, 0x0a /* Public */,
      20,    1,  124,    2, 0x0a /* Public */,
      21,    1,  127,    2, 0x0a /* Public */,
      22,    1,  130,    2, 0x0a /* Public */,
      23,    0,  133,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::QFont,   17,
    QMetaType::Void, QMetaType::QFont,   17,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,

 // properties: name, type, flags
      24, QMetaType::Bool, 0x00495103,
      25, QMetaType::Bool, 0x00495103,
      26, QMetaType::Bool, 0x00495103,
      27, QMetaType::Bool, 0x00495103,
      28, QMetaType::QFont, 0x00495103,
      29, QMetaType::QFont, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,

       0        // eod
};

void QQuickAbstractFontDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickAbstractFontDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->scalableFontsChanged(); break;
        case 1: _t->nonScalableFontsChanged(); break;
        case 2: _t->monospacedFontsChanged(); break;
        case 3: _t->proportionalFontsChanged(); break;
        case 4: _t->fontChanged(); break;
        case 5: _t->currentFontChanged(); break;
        case 6: _t->selectionAccepted(); break;
        case 7: _t->setVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->setModality((*reinterpret_cast< Qt::WindowModality(*)>(_a[1]))); break;
        case 9: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 11: _t->setCurrentFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 12: _t->setScalableFonts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setNonScalableFonts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->setMonospacedFonts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setProportionalFonts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->accept(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::scalableFontsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::nonScalableFontsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::monospacedFontsChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::proportionalFontsChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::fontChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::currentFontChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickAbstractFontDialog::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickAbstractFontDialog::selectionAccepted)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickAbstractFontDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->scalableFonts(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->nonScalableFonts(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->monospacedFonts(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->proportionalFonts(); break;
        case 4: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 5: *reinterpret_cast< QFont*>(_v) = _t->currentFont(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickAbstractFontDialog *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScalableFonts(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setNonScalableFonts(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setMonospacedFonts(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setProportionalFonts(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setFont(*reinterpret_cast< QFont*>(_v)); break;
        case 5: _t->setCurrentFont(*reinterpret_cast< QFont*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QQuickAbstractFontDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickAbstractDialog::staticMetaObject>(),
    qt_meta_stringdata_QQuickAbstractFontDialog.data,
    qt_meta_data_QQuickAbstractFontDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickAbstractFontDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickAbstractFontDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickAbstractFontDialog.stringdata0))
        return static_cast<void*>(this);
    return QQuickAbstractDialog::qt_metacast(_clname);
}

int QQuickAbstractFontDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickAbstractDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickAbstractFontDialog::scalableFontsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickAbstractFontDialog::nonScalableFontsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickAbstractFontDialog::monospacedFontsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickAbstractFontDialog::proportionalFontsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickAbstractFontDialog::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickAbstractFontDialog::currentFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickAbstractFontDialog::selectionAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
