/****************************************************************************
** Meta object code from reading C++ file 'qquickwheelarea_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/controls/Private/qquickwheelarea_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickwheelarea_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickWheelArea1_t {
    QByteArrayData data[23];
    char stringdata0[427];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickWheelArea1_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickWheelArea1_t qt_meta_stringdata_QQuickWheelArea1 = {
    {
QT_MOC_LITERAL(0, 0, 16), // "QQuickWheelArea1"
QT_MOC_LITERAL(1, 17, 20), // "verticalValueChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 27), // "verticalMinimumValueChanged"
QT_MOC_LITERAL(4, 67, 27), // "verticalMaximumValueChanged"
QT_MOC_LITERAL(5, 95, 22), // "horizontalValueChanged"
QT_MOC_LITERAL(6, 118, 29), // "horizontalMinimumValueChanged"
QT_MOC_LITERAL(7, 148, 29), // "horizontalMaximumValueChanged"
QT_MOC_LITERAL(8, 178, 18), // "verticalWheelMoved"
QT_MOC_LITERAL(9, 197, 20), // "horizontalWheelMoved"
QT_MOC_LITERAL(10, 218, 18), // "scrollSpeedChanged"
QT_MOC_LITERAL(11, 237, 13), // "activeChanged"
QT_MOC_LITERAL(12, 251, 13), // "verticalDelta"
QT_MOC_LITERAL(13, 265, 15), // "horizontalDelta"
QT_MOC_LITERAL(14, 281, 22), // "horizontalMinimumValue"
QT_MOC_LITERAL(15, 304, 22), // "horizontalMaximumValue"
QT_MOC_LITERAL(16, 327, 20), // "verticalMinimumValue"
QT_MOC_LITERAL(17, 348, 20), // "verticalMaximumValue"
QT_MOC_LITERAL(18, 369, 15), // "horizontalValue"
QT_MOC_LITERAL(19, 385, 13), // "verticalValue"
QT_MOC_LITERAL(20, 399, 11), // "scrollSpeed"
QT_MOC_LITERAL(21, 411, 6), // "active"
QT_MOC_LITERAL(22, 418, 8) // "inverted"

    },
    "QQuickWheelArea1\0verticalValueChanged\0"
    "\0verticalMinimumValueChanged\0"
    "verticalMaximumValueChanged\0"
    "horizontalValueChanged\0"
    "horizontalMinimumValueChanged\0"
    "horizontalMaximumValueChanged\0"
    "verticalWheelMoved\0horizontalWheelMoved\0"
    "scrollSpeedChanged\0activeChanged\0"
    "verticalDelta\0horizontalDelta\0"
    "horizontalMinimumValue\0horizontalMaximumValue\0"
    "verticalMinimumValue\0verticalMaximumValue\0"
    "horizontalValue\0verticalValue\0scrollSpeed\0"
    "active\0inverted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickWheelArea1[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
      11,   74, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    0,   65,    2, 0x06 /* Public */,
       4,    0,   66,    2, 0x06 /* Public */,
       5,    0,   67,    2, 0x06 /* Public */,
       6,    0,   68,    2, 0x06 /* Public */,
       7,    0,   69,    2, 0x06 /* Public */,
       8,    0,   70,    2, 0x06 /* Public */,
       9,    0,   71,    2, 0x06 /* Public */,
      10,    0,   72,    2, 0x06 /* Public */,
      11,    0,   73,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      12, QMetaType::QReal, 0x00495103,
      13, QMetaType::QReal, 0x00495103,
      14, QMetaType::QReal, 0x00495103,
      15, QMetaType::QReal, 0x00495103,
      16, QMetaType::QReal, 0x00495103,
      17, QMetaType::QReal, 0x00495103,
      18, QMetaType::QReal, 0x00495103,
      19, QMetaType::QReal, 0x00495103,
      20, QMetaType::QReal, 0x00495103,
      21, QMetaType::Bool, 0x00495103,
      22, QMetaType::Bool, 0x00095001,

 // properties: notify_signal_id
       6,
       7,
       4,
       5,
       1,
       2,
       3,
       0,
       8,
       9,
       0,

       0        // eod
};

void QQuickWheelArea1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickWheelArea1 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->verticalValueChanged(); break;
        case 1: _t->verticalMinimumValueChanged(); break;
        case 2: _t->verticalMaximumValueChanged(); break;
        case 3: _t->horizontalValueChanged(); break;
        case 4: _t->horizontalMinimumValueChanged(); break;
        case 5: _t->horizontalMaximumValueChanged(); break;
        case 6: _t->verticalWheelMoved(); break;
        case 7: _t->horizontalWheelMoved(); break;
        case 8: _t->scrollSpeedChanged(); break;
        case 9: _t->activeChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::verticalValueChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::verticalMinimumValueChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::verticalMaximumValueChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::horizontalValueChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::horizontalMinimumValueChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::horizontalMaximumValueChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::verticalWheelMoved)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::horizontalWheelMoved)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::scrollSpeedChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QQuickWheelArea1::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickWheelArea1::activeChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickWheelArea1 *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->verticalDelta(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->horizontalDelta(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->horizontalMinimumValue(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->horizontalMaximumValue(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->verticalMinimumValue(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->verticalMaximumValue(); break;
        case 6: *reinterpret_cast< qreal*>(_v) = _t->horizontalValue(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->verticalValue(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->scrollSpeed(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->isActive(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->isInverted(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickWheelArea1 *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVerticalDelta(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setHorizontalDelta(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setHorizontalMinimumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setHorizontalMaximumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 4: _t->setVerticalMinimumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setVerticalMaximumValue(*reinterpret_cast< qreal*>(_v)); break;
        case 6: _t->setHorizontalValue(*reinterpret_cast< qreal*>(_v)); break;
        case 7: _t->setVerticalValue(*reinterpret_cast< qreal*>(_v)); break;
        case 8: _t->setScrollSpeed(*reinterpret_cast< qreal*>(_v)); break;
        case 9: _t->setActive(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QQuickWheelArea1::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_QQuickWheelArea1.data,
    qt_meta_data_QQuickWheelArea1,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickWheelArea1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickWheelArea1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickWheelArea1.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QQuickWheelArea1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickWheelArea1::verticalValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickWheelArea1::verticalMinimumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuickWheelArea1::verticalMaximumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuickWheelArea1::horizontalValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuickWheelArea1::horizontalMinimumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickWheelArea1::horizontalMaximumValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickWheelArea1::verticalWheelMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuickWheelArea1::horizontalWheelMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuickWheelArea1::scrollSpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuickWheelArea1::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
